Class: Paperclip::Processor

Inherits:
Object
  • Object
show all
Defined in:
lib/paperclip/processor.rb

Overview

Paperclip processors allow you to modify attached files when they are attached in any way you are able. Paperclip itself uses command-line programs for its included Thumbnail processor, but custom processors are not required to follow suit.

Processors are required to be defined inside the Paperclip module and are also required to be a subclass of Paperclip::Processor. There is only one method you must implement to properly be a subclass: #make, but #initialize may also be of use. #initialize accepts 3 arguments: the file that will be operated on (which is an instance of File), a hash of options that were defined in has_attached_file's style hash, and the Paperclip::Attachment itself. These are set as instance variables that can be used within #make.

#make must return an instance of File (Tempfile is acceptable) which contains the results of the processing.

Direct Known Subclasses

Thumbnail

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(file, options = {}, attachment = nil) ⇒ Processor

Returns a new instance of Processor.



23
24
25
26
27
# File 'lib/paperclip/processor.rb', line 23

def initialize(file, options = {}, attachment = nil)
  @file = file
  @options = options
  @attachment = attachment
end

Instance Attribute Details

#attachmentObject

Returns the value of attribute attachment.



21
22
23
# File 'lib/paperclip/processor.rb', line 21

def attachment
  @attachment
end

#fileObject

Returns the value of attribute file.



21
22
23
# File 'lib/paperclip/processor.rb', line 21

def file
  @file
end

#optionsObject

Returns the value of attribute options.



21
22
23
# File 'lib/paperclip/processor.rb', line 21

def options
  @options
end

Class Method Details

.make(file, options = {}, attachment = nil) ⇒ Object



31
32
33
# File 'lib/paperclip/processor.rb', line 31

def self.make(file, options = {}, attachment = nil)
  new(file, options, attachment).make
end

Instance Method Details

#convert(arguments = nil, interpolation_values = {}) ⇒ Object



35
36
37
# File 'lib/paperclip/processor.rb', line 35

def convert(arguments = nil, interpolation_values = {})
  Paperclip::Commands::ImageMagick.convert(arguments, interpolation_values)
end

#identify(arguments = nil, interpolation_values = {}) ⇒ Object



39
40
41
# File 'lib/paperclip/processor.rb', line 39

def identify(arguments = nil, interpolation_values = {})
  Paperclip::Commands::ImageMagick.identify(arguments, interpolation_values)
end

#makeObject



29
# File 'lib/paperclip/processor.rb', line 29

def make; end